from GoogleNews import GoogleNews
from newspaper import Article

def getGoogleNewsLink(start,end,counts, keystring):
    googlenews=GoogleNews(start=start,end=end)
    googlenews.search(keystring)
    for i in range(0,counts):
        googlenews.getpage(i)
        result=googlenews.result()
        df=pd.DataFrame(result)
    return df


from setuptools import setup, find_packages

setup(
    name='msba_wan',
    version='0.1.3',
    description='For fun',
    author='Xuhu Wan',
    author_email='xuhu.wan@gmail.com',
    packages=find_packages(),
    install_requires=[
        'numpy',
        'pandas',
        "TextBlob",
        "GoogleNews",
        "tweepy",
        "pyLDAvis",
        "newspaper3k",
        "wordcloud",
        "stop_words",
        "gensim"        
    ],
)
